gnunet-svn
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[GNUnet-SVN] [libmicrohttpd] 01/02: daemon.c: renamed MHD_select_thread(


From: gnunet
Subject: [GNUnet-SVN] [libmicrohttpd] 01/02: daemon.c: renamed MHD_select_thread() -> MHD_polling_thread() for clarity
Date: Sun, 29 Oct 2017 19:17:28 +0100

This is an automated email from the git hooks/post-receive script.

karlson2k pushed a commit to branch master
in repository libmicrohttpd.

commit 5177e37a4147faf58b58167efd7a0411d668d73e
Author: Evgeny Grin (Karlson2k) <address@hidden>
AuthorDate: Sun Oct 29 20:02:57 2017 +0300

    daemon.c: renamed MHD_select_thread() -> MHD_polling_thread() for clarity
---
 src/microhttpd/daemon.c | 8 ++++----
 1 file changed, 4 insertions(+), 4 deletions(-)

diff --git a/src/microhttpd/daemon.c b/src/microhttpd/daemon.c
index 8a9c74e7..41396af5 100644
--- a/src/microhttpd/daemon.c
+++ b/src/microhttpd/daemon.c
@@ -4359,14 +4359,14 @@ close_connection (struct MHD_Connection *pos)
 
 
 /**
  * Thread that runs the select loop until the daemon
  * is explicitly shut down.
  *
  * @param cls `struct MHD_Deamon` to run select loop in a thread for
  * @return always 0 (on shutdown)
  */
 static MHD_THRD_RTRN_TYPE_ MHD_THRD_CALL_SPEC_
-MHD_select_thread (void *cls)
+MHD_polling_thread (void *cls)
 {
   struct MHD_Daemon *daemon = cls;
 
@@ -5878,7 +5878,7 @@ MHD_start_daemon_va (unsigned int flags,
                                     (*pflags & MHD_USE_THREAD_PER_CONNECTION) ?
                                     "MHD-listen" : "MHD-single",
                                     daemon->thread_stack_size,
-                                    &MHD_select_thread,
+                                    &MHD_polling_thread,
                                     daemon) ) )
     {
 #ifdef HAVE_MESSAGES
@@ -5976,7 +5976,7 @@ MHD_start_daemon_va (unsigned int flags,
           if (! MHD_create_named_thread_ (&d->pid,
                                           "MHD-worker",
                                           daemon->thread_stack_size,
-                                          &MHD_select_thread,
+                                          &MHD_polling_thread,
                                           d))
             {
 #ifdef HAVE_MESSAGES
@@ -4359,14 +4359,14 @@ close_connection (struct MHD_Connection *pos)
 
 /**
- * Thread that runs the select loop until the daemon
+ * Thread that runs the polling loop until the daemon
  * is explicitly shut down.
  *

-- 
To stop receiving notification emails like this one, please contact
address@hidden



reply via email to

[Prev in Thread] Current Thread [Next in Thread]